﻿using System;
using System.Collections.Generic;
using System.Linq;
using Orchard.Caching;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Drivers;
using Orchard.Localization;
using Orchard.Media.Services;
using CloudConstruct.AppleTouchIcon.Models;
using CloudConstruct.AppleTouchIcon.ViewModels;

namespace CloudConstruct.AppleTouchIcon.Drivers
{
    public class AppleTouchIconSettingsPartDriver : ContentPartDriver<AppleTouchIconSettingsPart> {
        private const string _appletouchiconMediaFolder = "apple-touch-icon";
        private readonly IMediaService _mediaService;
        private readonly ISignals _signals;

        public AppleTouchIconSettingsPartDriver(IMediaService mediaService, ISignals signals) {
            T = NullLocalizer.Instance;
            _mediaService = mediaService;
            _signals = signals;
        }

        public Localizer T { get; set; }

        protected override string Prefix { get { return "AppleTouchIconSettings"; } }

        protected override DriverResult Editor(AppleTouchIconSettingsPart part, dynamic shapeHelper) {
            List<string> appletouchiconSuggestions = null;
            var rootMediaFolders = _mediaService
                .GetMediaFolders(".")
                .Where(f => f.Name.Equals(_appletouchiconMediaFolder, StringComparison.OrdinalIgnoreCase));
            if (rootMediaFolders.Any()) {
                appletouchiconSuggestions = new List<string>(
                    _mediaService.GetMediaFiles(_appletouchiconMediaFolder)
                    .Select(f => _mediaService.GetPublicUrl(_appletouchiconMediaFolder + "/" + f.Name)));
            }

            return ContentShape("Parts_AppleTouchIcon_SiteSettings",
                               () => shapeHelper.EditorTemplate(
                                   TemplateName: "Parts.AppleTouchIcon.SiteSettings",
                                   Model: new AppleTouchIconSettingsViewModel {
                                       AppleTouchIconUrl = part.Record.AppleTouchIconUrl,
                                       AppleTouchIconUrlSuggestions = appletouchiconSuggestions
                                   },
                                   Prefix: Prefix));
        }

        protected override DriverResult Editor(AppleTouchIconSettingsPart part, IUpdateModel updater, dynamic shapeHelper) {
            updater.TryUpdateModel(part.Record, Prefix, null, null);
            _signals.Trigger("CloudConstruct.AppleTouchIcon.Changed");
            return Editor(part, shapeHelper);
        }
    }
}