﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using Orchard;
using Orchard.Caching;
using CloudConstruct.AppleTouchIcon.Models;

namespace CloudConstruct.AppleTouchIcon.Service {
    public interface IAppleTouchIconService : IDependency {
        string GetAppleTouchIconUrl();
    }

    public class AppleTouchIconService : IAppleTouchIconService {
        private readonly IWorkContextAccessor _wca;
        private readonly ICacheManager _cacheManager;
        private readonly ISignals _signals;

        public AppleTouchIconService(IWorkContextAccessor wca, ICacheManager cacheManager, ISignals signals) {
            _wca = wca;
            _cacheManager = cacheManager;
            _signals = signals;
        }

        public string GetAppleTouchIconUrl()
        {
            return _cacheManager.Get(
                "CloudConstruct.AppleTouchIcon.Url",
                ctx => {
                    ctx.Monitor(_signals.When("CloudConstruct.AppleTouchIcon.Changed"));
                    WorkContext workContext = _wca.GetContext();
                    var appletouchiconSettings =
                        (AppleTouchIconSettingsPart) workContext
                                                  .CurrentSite
                                                  .ContentItem
                                                  .Get(typeof (AppleTouchIconSettingsPart));
                    return appletouchiconSettings.AppleTouchIconUrl;
                });
        }
    }
}