﻿using System.Linq;
using Orchard;
using Orchard.DisplayManagement.Descriptors;
using Orchard.UI.Resources;
using CloudConstruct.AppleTouchIcon.Models;
using CloudConstruct.AppleTouchIcon.Service;

namespace CloudConstruct.AppleTouchIcon.Shapes
{
    public class AppleTouchIconShapes : IShapeTableProvider {
        private readonly IWorkContextAccessor _wca;
        private readonly IAppleTouchIconService _appletouchiconService;

        public AppleTouchIconShapes(IWorkContextAccessor wca, IAppleTouchIconService appletouchiconService)
        {
            _wca = wca;
            _appletouchiconService = appletouchiconService;
        }

        public void Discover(ShapeTableBuilder builder) {
            builder.Describe("HeadLinks")
                .OnDisplaying(shapeDisplayingContext => {
                    string appletouchiconUrl = _appletouchiconService.GetAppleTouchIconUrl();
                    if (!string.IsNullOrWhiteSpace(appletouchiconUrl))
                    {
                        // Get the current apple touch icon from head
                        var resourceManager = _wca.GetContext().Resolve<IResourceManager>();
                        var links = resourceManager.GetRegisteredLinks();
                        var currentAppleTouchIcon = links
                            .Where(l => l.Rel == "apple-touch-icon")
                            .FirstOrDefault();
                        // Modify if found
                        if (currentAppleTouchIcon != default(LinkEntry))
                        {
                            currentAppleTouchIcon.Href = appletouchiconUrl;
                        }
                        else {
                            // Add the new one
                            resourceManager.RegisterLink(new LinkEntry {
                                Type = "image/x-icon",
                                Href = appletouchiconUrl,
                                Rel = "apple-touch-icon",
                            });
                        }
                    }
                });
        }
    }
}